@@ -2,7 +2,7 @@ import aiohttp
 import base64
 import json
 
-from aiohttp import ClientResponseError
+from aiohttp import ClientResponseError, ClientConnectorError
 
 from async_near.exceptions.execution import RpcNotAvailableError
 from async_near.exceptions.provider import (
@@ -58,8 +58,11 @@ class JsonProvider(object):
                 if self._rpc_addresses[0] != rpc_addr:
                     self._rpc_addresses.remove(rpc_addr)
                     self._rpc_addresses.insert(0, rpc_addr)
+                break
             except ClientResponseError:
                 continue
+            except ClientConnectorError:
+                continue
             except ConnectionError:
                 continue
 
